// ignore_for_file: type=lint

import 'package:json_annotation/json_annotation.dart';
import 'package:json_annotation/json_annotation.dart' as json;
import 'package:collection/collection.dart';
import 'dart:convert';

import 'package:chopper/chopper.dart';

import 'client_mapping.dart';
import 'dart:async';
import 'package:http/http.dart' as http;
import 'package:http/http.dart' show MultipartFile;
import 'package:chopper/chopper.dart' as chopper;
import 'swagger.enums.swagger.dart' as enums;
export 'swagger.enums.swagger.dart';

part 'swagger.swagger.chopper.dart';
part 'swagger.swagger.g.dart';

// **************************************************************************
// SwaggerChopperGenerator
// **************************************************************************

@ChopperApi()
abstract class Swagger extends ChopperService {
  static Swagger create({
    ChopperClient? client,
    http.Client? httpClient,
    Authenticator? authenticator,
    ErrorConverter? errorConverter,
    Converter? converter,
    Uri? baseUrl,
    List<Interceptor>? interceptors,
  }) {
    if (client != null) {
      return _$Swagger(client);
    }

    final newClient = ChopperClient(
        services: [_$Swagger()],
        converter: converter ?? $JsonSerializableConverter(),
        interceptors: interceptors ?? [],
        client: httpClient,
        authenticator: authenticator,
        errorConverter: errorConverter,
        baseUrl: baseUrl ?? Uri.parse('http://natinfo.retiolus.net/api'));
    return _$Swagger(newClient);
  }

  ///
  ///@param article_id Article unique identifier.
  Future<chopper.Response<LegifranceArticleGet$Response>> legifranceArticleGet(
      {String? articleId}) {
    generatedMapping.putIfAbsent(LegifranceArticleGet$Response,
        () => LegifranceArticleGet$Response.fromJsonFactory);

    return _legifranceArticleGet(articleId: articleId);
  }

  ///
  ///@param article_id Article unique identifier.
  @Get(path: '/legifrance/article/')
  Future<chopper.Response<LegifranceArticleGet$Response>> _legifranceArticleGet(
      {@Query('article_id') String? articleId});

  ///
  ///@param article_number The number of the legal article to look up.
  ///@param code_name The code name where the article is defined.
  Future<chopper.Response<LegifranceIdGet$Response>> legifranceIdGet({
    String? articleNumber,
    String? codeName,
  }) {
    generatedMapping.putIfAbsent(LegifranceIdGet$Response,
        () => LegifranceIdGet$Response.fromJsonFactory);

    return _legifranceIdGet(articleNumber: articleNumber, codeName: codeName);
  }

  ///
  ///@param article_number The number of the legal article to look up.
  ///@param code_name The code name where the article is defined.
  @Get(path: '/legifrance/id/')
  Future<chopper.Response<LegifranceIdGet$Response>> _legifranceIdGet({
    @Query('article_number') String? articleNumber,
    @Query('code_name') String? codeName,
  });

  ///
  ///@param search_text Query for suggestion results.
  Future<chopper.Response<List<dynamic>>> legifranceSuggestGet(
      {String? searchText}) {
    return _legifranceSuggestGet(searchText: searchText);
  }

  ///
  ///@param search_text Query for suggestion results.
  @Get(path: '/legifrance/suggest/')
  Future<chopper.Response<List<dynamic>>> _legifranceSuggestGet(
      {@Query('search_text') String? searchText});

  ///
  Future<chopper.Response<List<Natinf>>> natinfoGet() {
    generatedMapping.putIfAbsent(Natinf, () => Natinf.fromJsonFactory);

    return _natinfoGet();
  }

  ///
  @Get(path: '/natinfo/')
  Future<chopper.Response<List<Natinf>>> _natinfoGet();

  ///
  ///@param data
  Future<chopper.Response<Natinf>> natinfoNatinfEditPost(
      {required NatinfUpdate? data}) {
    generatedMapping.putIfAbsent(
        NatinfUpdate, () => NatinfUpdate.fromJsonFactory);
    generatedMapping.putIfAbsent(Natinf, () => Natinf.fromJsonFactory);

    return _natinfoNatinfEditPost(data: data);
  }

  ///
  ///@param data
  @Post(path: '/natinfo/natinf/edit/')
  Future<chopper.Response<Natinf>> _natinfoNatinfEditPost(
      {@Body() required NatinfUpdate? data});

  ///
  Future<chopper.Response> natinfoNfiClassesClasseIdGet(
      {required String? classeId}) {
    return _natinfoNfiClassesClasseIdGet(classeId: classeId);
  }

  ///
  @Get(path: '/natinfo/nfi/classes/{classe_id}/')
  Future<chopper.Response> _natinfoNfiClassesClasseIdGet(
      {@Path('classe_id') required String? classeId});

  ///
  Future<chopper.Response> natinfoNfiDivisionsDivisionIdGet(
      {required String? divisionId}) {
    return _natinfoNfiDivisionsDivisionIdGet(divisionId: divisionId);
  }

  ///
  @Get(path: '/natinfo/nfi/divisions/{division_id}/')
  Future<chopper.Response> _natinfoNfiDivisionsDivisionIdGet(
      {@Path('division_id') required String? divisionId});

  ///
  Future<chopper.Response> natinfoNfiGroupesGroupeIdGet(
      {required String? groupeId}) {
    return _natinfoNfiGroupesGroupeIdGet(groupeId: groupeId);
  }

  ///
  @Get(path: '/natinfo/nfi/groupes/{groupe_id}/')
  Future<chopper.Response> _natinfoNfiGroupesGroupeIdGet(
      {@Path('groupe_id') required String? groupeId});

  ///
  Future<chopper.Response> natinfoNfiSectionsGet() {
    return _natinfoNfiSectionsGet();
  }

  ///
  @Get(path: '/natinfo/nfi/sections/')
  Future<chopper.Response> _natinfoNfiSectionsGet();

  ///
  Future<chopper.Response> natinfoNfiSectionsSectionIdGet(
      {required String? sectionId}) {
    return _natinfoNfiSectionsSectionIdGet(sectionId: sectionId);
  }

  ///
  @Get(path: '/natinfo/nfi/sections/{section_id}/')
  Future<chopper.Response> _natinfoNfiSectionsSectionIdGet(
      {@Path('section_id') required String? sectionId});

  ///
  Future<chopper.Response> natinfoNfiSousClassesSousClasseIdGet(
      {required String? sousClasseId}) {
    return _natinfoNfiSousClassesSousClasseIdGet(sousClasseId: sousClasseId);
  }

  ///
  @Get(path: '/natinfo/nfi/sous-classes/{sous_classe_id}/')
  Future<chopper.Response> _natinfoNfiSousClassesSousClasseIdGet(
      {@Path('sous_classe_id') required String? sousClasseId});

  ///
  ///@param q Search query string (keywords, code, article, etc.)
  ///@param paginate Enable pagination (true/false)
  ///@param page Page number (optional, only if paginate=true, defaults to 1)
  Future<chopper.Response<List<Natinf>>> natinfoSearchGet({
    String? q,
    bool? paginate,
    int? page,
  }) {
    generatedMapping.putIfAbsent(Natinf, () => Natinf.fromJsonFactory);

    return _natinfoSearchGet(q: q, paginate: paginate, page: page);
  }

  ///
  ///@param q Search query string (keywords, code, article, etc.)
  ///@param paginate Enable pagination (true/false)
  ///@param page Page number (optional, only if paginate=true, defaults to 1)
  @Get(path: '/natinfo/search/')
  Future<chopper.Response<List<Natinf>>> _natinfoSearchGet({
    @Query('q') String? q,
    @Query('paginate') bool? paginate,
    @Query('page') int? page,
  });

  ///
  ///@param abreviation Normalized abbreviation for the text type (punctuation/case insensitive).
  ///@param libelle The displayed label (case and whitespace insensitive).
  ///@param libelle_legifrance_api Label used in the Legifrance API (case and whitespace insensitive).
  Future<chopper.Response<NatinfoTexteTypeLibelleGet$Response>>
      natinfoTexteTypeLibelleGet({
    String? abreviation,
    String? libelle,
    String? libelleLegifranceApi,
  }) {
    generatedMapping.putIfAbsent(NatinfoTexteTypeLibelleGet$Response,
        () => NatinfoTexteTypeLibelleGet$Response.fromJsonFactory);

    return _natinfoTexteTypeLibelleGet(
        abreviation: abreviation,
        libelle: libelle,
        libelleLegifranceApi: libelleLegifranceApi);
  }

  ///
  ///@param abreviation Normalized abbreviation for the text type (punctuation/case insensitive).
  ///@param libelle The displayed label (case and whitespace insensitive).
  ///@param libelle_legifrance_api Label used in the Legifrance API (case and whitespace insensitive).
  @Get(path: '/natinfo/texte-type-libelle/')
  Future<chopper.Response<NatinfoTexteTypeLibelleGet$Response>>
      _natinfoTexteTypeLibelleGet({
    @Query('abreviation') String? abreviation,
    @Query('libelle') String? libelle,
    @Query('libelle_legifrance_api') String? libelleLegifranceApi,
  });
}

@JsonSerializable(explicitToJson: true)
class Natinf {
  const Natinf({
    this.id,
    this.numeroNatinf,
    this.natureInfraction,
    this.qualificationInfraction,
    this.definiePar,
    this.reprimeePar,
    this.sanctionsEncourues,
    this.controleAlcoolemie,
    this.depistageImpregnationAlcoolique,
    this.depistageStupefiants,
    this.retraitPoints,
    this.retentionPermisConduire,
    this.immobilisationVehicule,
    this.miseEnFourriere,
    this.mesuresComplementaires,
    this.observations,
    this.lastEdited,
    this.typesAmendeForfaitaire,
    this.nfiSection,
    this.nfiDivision,
    this.nfiGroupe,
    this.nfiClasse,
    this.nfiSousClasse,
    this.modesProcesVerbal,
  });

  factory Natinf.fromJson(Map<String, dynamic> json) => _$NatinfFromJson(json);

  static const toJsonFactory = _$NatinfToJson;
  Map<String, dynamic> toJson() => _$NatinfToJson(this);

  @JsonKey(name: 'id')
  final int? id;
  @JsonKey(name: 'numero_natinf')
  final String? numeroNatinf;
  @JsonKey(name: 'nature_infraction')
  final String? natureInfraction;
  @JsonKey(name: 'qualification_infraction')
  final String? qualificationInfraction;
  @JsonKey(name: 'definie_par')
  final String? definiePar;
  @JsonKey(name: 'reprimee_par')
  final String? reprimeePar;
  @JsonKey(name: 'sanctions_encourues')
  final String? sanctionsEncourues;
  @JsonKey(
    name: 'controle_alcoolemie',
    toJson: natinfControleAlcoolemieNullableToJson,
    fromJson: natinfControleAlcoolemieNullableFromJson,
  )
  final enums.NatinfControleAlcoolemie? controleAlcoolemie;
  @JsonKey(
    name: 'depistage_impregnation_alcoolique',
    toJson: natinfDepistageImpregnationAlcooliqueNullableToJson,
    fromJson: natinfDepistageImpregnationAlcooliqueNullableFromJson,
  )
  final enums.NatinfDepistageImpregnationAlcoolique?
      depistageImpregnationAlcoolique;
  @JsonKey(
    name: 'depistage_stupefiants',
    toJson: natinfDepistageStupefiantsNullableToJson,
    fromJson: natinfDepistageStupefiantsNullableFromJson,
  )
  final enums.NatinfDepistageStupefiants? depistageStupefiants;
  @JsonKey(name: 'retrait_points')
  final int? retraitPoints;
  @JsonKey(
    name: 'retention_permis_conduire',
    toJson: natinfRetentionPermisConduireNullableToJson,
    fromJson: natinfRetentionPermisConduireNullableFromJson,
  )
  final enums.NatinfRetentionPermisConduire? retentionPermisConduire;
  @JsonKey(
    name: 'immobilisation_vehicule',
    toJson: natinfImmobilisationVehiculeNullableToJson,
    fromJson: natinfImmobilisationVehiculeNullableFromJson,
  )
  final enums.NatinfImmobilisationVehicule? immobilisationVehicule;
  @JsonKey(
    name: 'mise_en_fourriere',
    toJson: natinfMiseEnFourriereNullableToJson,
    fromJson: natinfMiseEnFourriereNullableFromJson,
  )
  final enums.NatinfMiseEnFourriere? miseEnFourriere;
  @JsonKey(name: 'mesures_complementaires')
  final String? mesuresComplementaires;
  @JsonKey(name: 'observations')
  final String? observations;
  @JsonKey(name: 'last_edited')
  final DateTime? lastEdited;
  @JsonKey(name: 'types_amende_forfaitaire')
  final int? typesAmendeForfaitaire;
  @JsonKey(name: 'nfi_section')
  final String? nfiSection;
  @JsonKey(name: 'nfi_division')
  final String? nfiDivision;
  @JsonKey(name: 'nfi_groupe')
  final String? nfiGroupe;
  @JsonKey(name: 'nfi_classe')
  final String? nfiClasse;
  @JsonKey(name: 'nfi_sous_classe')
  final String? nfiSousClasse;
  @JsonKey(name: 'modes_proces_verbal', defaultValue: <int>[])
  final List<int>? modesProcesVerbal;
  static const fromJsonFactory = _$NatinfFromJson;

  @override
  bool operator ==(Object other) {
    return identical(this, other) ||
        (other is Natinf &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.numeroNatinf, numeroNatinf) ||
                const DeepCollectionEquality()
                    .equals(other.numeroNatinf, numeroNatinf)) &&
            (identical(other.natureInfraction, natureInfraction) ||
                const DeepCollectionEquality()
                    .equals(other.natureInfraction, natureInfraction)) &&
            (identical(other.qualificationInfraction, qualificationInfraction) ||
                const DeepCollectionEquality().equals(
                    other.qualificationInfraction, qualificationInfraction)) &&
            (identical(other.definiePar, definiePar) ||
                const DeepCollectionEquality()
                    .equals(other.definiePar, definiePar)) &&
            (identical(other.reprimeePar, reprimeePar) ||
                const DeepCollectionEquality()
                    .equals(other.reprimeePar, reprimeePar)) &&
            (identical(other.sanctionsEncourues, sanctionsEncourues) ||
                const DeepCollectionEquality()
                    .equals(other.sanctionsEncourues, sanctionsEncourues)) &&
            (identical(other.controleAlcoolemie, controleAlcoolemie) ||
                const DeepCollectionEquality()
                    .equals(other.controleAlcoolemie, controleAlcoolemie)) &&
            (identical(other.depistageImpregnationAlcoolique, depistageImpregnationAlcoolique) ||
                const DeepCollectionEquality().equals(
                    other.depistageImpregnationAlcoolique,
                    depistageImpregnationAlcoolique)) &&
            (identical(other.depistageStupefiants, depistageStupefiants) ||
                const DeepCollectionEquality().equals(
                    other.depistageStupefiants, depistageStupefiants)) &&
            (identical(other.retraitPoints, retraitPoints) ||
                const DeepCollectionEquality()
                    .equals(other.retraitPoints, retraitPoints)) &&
            (identical(other.retentionPermisConduire, retentionPermisConduire) ||
                const DeepCollectionEquality().equals(
                    other.retentionPermisConduire, retentionPermisConduire)) &&
            (identical(other.immobilisationVehicule, immobilisationVehicule) ||
                const DeepCollectionEquality().equals(
                    other.immobilisationVehicule, immobilisationVehicule)) &&
            (identical(other.miseEnFourriere, miseEnFourriere) ||
                const DeepCollectionEquality()
                    .equals(other.miseEnFourriere, miseEnFourriere)) &&
            (identical(other.mesuresComplementaires, mesuresComplementaires) ||
                const DeepCollectionEquality().equals(other.mesuresComplementaires, mesuresComplementaires)) &&
            (identical(other.observations, observations) || const DeepCollectionEquality().equals(other.observations, observations)) &&
            (identical(other.lastEdited, lastEdited) || const DeepCollectionEquality().equals(other.lastEdited, lastEdited)) &&
            (identical(other.typesAmendeForfaitaire, typesAmendeForfaitaire) || const DeepCollectionEquality().equals(other.typesAmendeForfaitaire, typesAmendeForfaitaire)) &&
            (identical(other.nfiSection, nfiSection) || const DeepCollectionEquality().equals(other.nfiSection, nfiSection)) &&
            (identical(other.nfiDivision, nfiDivision) || const DeepCollectionEquality().equals(other.nfiDivision, nfiDivision)) &&
            (identical(other.nfiGroupe, nfiGroupe) || const DeepCollectionEquality().equals(other.nfiGroupe, nfiGroupe)) &&
            (identical(other.nfiClasse, nfiClasse) || const DeepCollectionEquality().equals(other.nfiClasse, nfiClasse)) &&
            (identical(other.nfiSousClasse, nfiSousClasse) || const DeepCollectionEquality().equals(other.nfiSousClasse, nfiSousClasse)) &&
            (identical(other.modesProcesVerbal, modesProcesVerbal) || const DeepCollectionEquality().equals(other.modesProcesVerbal, modesProcesVerbal)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(numeroNatinf) ^
      const DeepCollectionEquality().hash(natureInfraction) ^
      const DeepCollectionEquality().hash(qualificationInfraction) ^
      const DeepCollectionEquality().hash(definiePar) ^
      const DeepCollectionEquality().hash(reprimeePar) ^
      const DeepCollectionEquality().hash(sanctionsEncourues) ^
      const DeepCollectionEquality().hash(controleAlcoolemie) ^
      const DeepCollectionEquality().hash(depistageImpregnationAlcoolique) ^
      const DeepCollectionEquality().hash(depistageStupefiants) ^
      const DeepCollectionEquality().hash(retraitPoints) ^
      const DeepCollectionEquality().hash(retentionPermisConduire) ^
      const DeepCollectionEquality().hash(immobilisationVehicule) ^
      const DeepCollectionEquality().hash(miseEnFourriere) ^
      const DeepCollectionEquality().hash(mesuresComplementaires) ^
      const DeepCollectionEquality().hash(observations) ^
      const DeepCollectionEquality().hash(lastEdited) ^
      const DeepCollectionEquality().hash(typesAmendeForfaitaire) ^
      const DeepCollectionEquality().hash(nfiSection) ^
      const DeepCollectionEquality().hash(nfiDivision) ^
      const DeepCollectionEquality().hash(nfiGroupe) ^
      const DeepCollectionEquality().hash(nfiClasse) ^
      const DeepCollectionEquality().hash(nfiSousClasse) ^
      const DeepCollectionEquality().hash(modesProcesVerbal) ^
      runtimeType.hashCode;
}

extension $NatinfExtension on Natinf {
  Natinf copyWith(
      {int? id,
      String? numeroNatinf,
      String? natureInfraction,
      String? qualificationInfraction,
      String? definiePar,
      String? reprimeePar,
      String? sanctionsEncourues,
      enums.NatinfControleAlcoolemie? controleAlcoolemie,
      enums.NatinfDepistageImpregnationAlcoolique?
          depistageImpregnationAlcoolique,
      enums.NatinfDepistageStupefiants? depistageStupefiants,
      int? retraitPoints,
      enums.NatinfRetentionPermisConduire? retentionPermisConduire,
      enums.NatinfImmobilisationVehicule? immobilisationVehicule,
      enums.NatinfMiseEnFourriere? miseEnFourriere,
      String? mesuresComplementaires,
      String? observations,
      DateTime? lastEdited,
      int? typesAmendeForfaitaire,
      String? nfiSection,
      String? nfiDivision,
      String? nfiGroupe,
      String? nfiClasse,
      String? nfiSousClasse,
      List<int>? modesProcesVerbal}) {
    return Natinf(
        id: id ?? this.id,
        numeroNatinf: numeroNatinf ?? this.numeroNatinf,
        natureInfraction: natureInfraction ?? this.natureInfraction,
        qualificationInfraction:
            qualificationInfraction ?? this.qualificationInfraction,
        definiePar: definiePar ?? this.definiePar,
        reprimeePar: reprimeePar ?? this.reprimeePar,
        sanctionsEncourues: sanctionsEncourues ?? this.sanctionsEncourues,
        controleAlcoolemie: controleAlcoolemie ?? this.controleAlcoolemie,
        depistageImpregnationAlcoolique: depistageImpregnationAlcoolique ??
            this.depistageImpregnationAlcoolique,
        depistageStupefiants: depistageStupefiants ?? this.depistageStupefiants,
        retraitPoints: retraitPoints ?? this.retraitPoints,
        retentionPermisConduire:
            retentionPermisConduire ?? this.retentionPermisConduire,
        immobilisationVehicule:
            immobilisationVehicule ?? this.immobilisationVehicule,
        miseEnFourriere: miseEnFourriere ?? this.miseEnFourriere,
        mesuresComplementaires:
            mesuresComplementaires ?? this.mesuresComplementaires,
        observations: observations ?? this.observations,
        lastEdited: lastEdited ?? this.lastEdited,
        typesAmendeForfaitaire:
            typesAmendeForfaitaire ?? this.typesAmendeForfaitaire,
        nfiSection: nfiSection ?? this.nfiSection,
        nfiDivision: nfiDivision ?? this.nfiDivision,
        nfiGroupe: nfiGroupe ?? this.nfiGroupe,
        nfiClasse: nfiClasse ?? this.nfiClasse,
        nfiSousClasse: nfiSousClasse ?? this.nfiSousClasse,
        modesProcesVerbal: modesProcesVerbal ?? this.modesProcesVerbal);
  }

  Natinf copyWithWrapped(
      {Wrapped<int?>? id,
      Wrapped<String?>? numeroNatinf,
      Wrapped<String?>? natureInfraction,
      Wrapped<String?>? qualificationInfraction,
      Wrapped<String?>? definiePar,
      Wrapped<String?>? reprimeePar,
      Wrapped<String?>? sanctionsEncourues,
      Wrapped<enums.NatinfControleAlcoolemie?>? controleAlcoolemie,
      Wrapped<enums.NatinfDepistageImpregnationAlcoolique?>?
          depistageImpregnationAlcoolique,
      Wrapped<enums.NatinfDepistageStupefiants?>? depistageStupefiants,
      Wrapped<int?>? retraitPoints,
      Wrapped<enums.NatinfRetentionPermisConduire?>? retentionPermisConduire,
      Wrapped<enums.NatinfImmobilisationVehicule?>? immobilisationVehicule,
      Wrapped<enums.NatinfMiseEnFourriere?>? miseEnFourriere,
      Wrapped<String?>? mesuresComplementaires,
      Wrapped<String?>? observations,
      Wrapped<DateTime?>? lastEdited,
      Wrapped<int?>? typesAmendeForfaitaire,
      Wrapped<String?>? nfiSection,
      Wrapped<String?>? nfiDivision,
      Wrapped<String?>? nfiGroupe,
      Wrapped<String?>? nfiClasse,
      Wrapped<String?>? nfiSousClasse,
      Wrapped<List<int>?>? modesProcesVerbal}) {
    return Natinf(
        id: (id != null ? id.value : this.id),
        numeroNatinf:
            (numeroNatinf != null ? numeroNatinf.value : this.numeroNatinf),
        natureInfraction: (natureInfraction != null
            ? natureInfraction.value
            : this.natureInfraction),
        qualificationInfraction: (qualificationInfraction != null
            ? qualificationInfraction.value
            : this.qualificationInfraction),
        definiePar: (definiePar != null ? definiePar.value : this.definiePar),
        reprimeePar:
            (reprimeePar != null ? reprimeePar.value : this.reprimeePar),
        sanctionsEncourues: (sanctionsEncourues != null
            ? sanctionsEncourues.value
            : this.sanctionsEncourues),
        controleAlcoolemie: (controleAlcoolemie != null
            ? controleAlcoolemie.value
            : this.controleAlcoolemie),
        depistageImpregnationAlcoolique:
            (depistageImpregnationAlcoolique != null
                ? depistageImpregnationAlcoolique.value
                : this.depistageImpregnationAlcoolique),
        depistageStupefiants: (depistageStupefiants != null
            ? depistageStupefiants.value
            : this.depistageStupefiants),
        retraitPoints:
            (retraitPoints != null ? retraitPoints.value : this.retraitPoints),
        retentionPermisConduire: (retentionPermisConduire != null
            ? retentionPermisConduire.value
            : this.retentionPermisConduire),
        immobilisationVehicule: (immobilisationVehicule != null
            ? immobilisationVehicule.value
            : this.immobilisationVehicule),
        miseEnFourriere: (miseEnFourriere != null
            ? miseEnFourriere.value
            : this.miseEnFourriere),
        mesuresComplementaires: (mesuresComplementaires != null
            ? mesuresComplementaires.value
            : this.mesuresComplementaires),
        observations:
            (observations != null ? observations.value : this.observations),
        lastEdited: (lastEdited != null ? lastEdited.value : this.lastEdited),
        typesAmendeForfaitaire: (typesAmendeForfaitaire != null
            ? typesAmendeForfaitaire.value
            : this.typesAmendeForfaitaire),
        nfiSection: (nfiSection != null ? nfiSection.value : this.nfiSection),
        nfiDivision:
            (nfiDivision != null ? nfiDivision.value : this.nfiDivision),
        nfiGroupe: (nfiGroupe != null ? nfiGroupe.value : this.nfiGroupe),
        nfiClasse: (nfiClasse != null ? nfiClasse.value : this.nfiClasse),
        nfiSousClasse:
            (nfiSousClasse != null ? nfiSousClasse.value : this.nfiSousClasse),
        modesProcesVerbal: (modesProcesVerbal != null
            ? modesProcesVerbal.value
            : this.modesProcesVerbal));
  }
}

@JsonSerializable(explicitToJson: true)
class NatinfUpdate {
  const NatinfUpdate({
    required this.numeroNatinf,
    required this.changementsCommentaires,
    this.modesProcesVerbal,
    this.sanctionsEncourues,
    this.typesAmendeForfaitaire,
    this.controleAlcoolemie,
    this.depistageImpregnationAlcoolique,
    this.depistageStupefiants,
    this.retraitPoints,
    this.retentionPermisConduire,
    this.immobilisationVehicule,
    this.miseEnFourriere,
    this.mesuresComplementaires,
    this.observations,
    this.nfiSection,
    this.nfiDivision,
    this.nfiGroupe,
    this.nfiClasse,
    this.nfiSousClasse,
  });

  factory NatinfUpdate.fromJson(Map<String, dynamic> json) =>
      _$NatinfUpdateFromJson(json);

  static const toJsonFactory = _$NatinfUpdateToJson;
  Map<String, dynamic> toJson() => _$NatinfUpdateToJson(this);

  @JsonKey(name: 'numero_natinf')
  final String numeroNatinf;
  @JsonKey(name: 'changements_commentaires')
  final String changementsCommentaires;
  @JsonKey(name: 'modes_proces_verbal', defaultValue: <int>[])
  final List<int>? modesProcesVerbal;
  @JsonKey(name: 'sanctions_encourues')
  final String? sanctionsEncourues;
  @JsonKey(name: 'types_amende_forfaitaire')
  final int? typesAmendeForfaitaire;
  @JsonKey(
    name: 'controle_alcoolemie',
    toJson: natinfUpdateControleAlcoolemieNullableToJson,
    fromJson: natinfUpdateControleAlcoolemieNullableFromJson,
  )
  final enums.NatinfUpdateControleAlcoolemie? controleAlcoolemie;
  @JsonKey(
    name: 'depistage_impregnation_alcoolique',
    toJson: natinfUpdateDepistageImpregnationAlcooliqueNullableToJson,
    fromJson: natinfUpdateDepistageImpregnationAlcooliqueNullableFromJson,
  )
  final enums.NatinfUpdateDepistageImpregnationAlcoolique?
      depistageImpregnationAlcoolique;
  @JsonKey(
    name: 'depistage_stupefiants',
    toJson: natinfUpdateDepistageStupefiantsNullableToJson,
    fromJson: natinfUpdateDepistageStupefiantsNullableFromJson,
  )
  final enums.NatinfUpdateDepistageStupefiants? depistageStupefiants;
  @JsonKey(name: 'retrait_points')
  final int? retraitPoints;
  @JsonKey(
    name: 'retention_permis_conduire',
    toJson: natinfUpdateRetentionPermisConduireNullableToJson,
    fromJson: natinfUpdateRetentionPermisConduireNullableFromJson,
  )
  final enums.NatinfUpdateRetentionPermisConduire? retentionPermisConduire;
  @JsonKey(
    name: 'immobilisation_vehicule',
    toJson: natinfUpdateImmobilisationVehiculeNullableToJson,
    fromJson: natinfUpdateImmobilisationVehiculeNullableFromJson,
  )
  final enums.NatinfUpdateImmobilisationVehicule? immobilisationVehicule;
  @JsonKey(
    name: 'mise_en_fourriere',
    toJson: natinfUpdateMiseEnFourriereNullableToJson,
    fromJson: natinfUpdateMiseEnFourriereNullableFromJson,
  )
  final enums.NatinfUpdateMiseEnFourriere? miseEnFourriere;
  @JsonKey(name: 'mesures_complementaires')
  final String? mesuresComplementaires;
  @JsonKey(name: 'observations')
  final String? observations;
  @JsonKey(name: 'nfi_section')
  final String? nfiSection;
  @JsonKey(name: 'nfi_division')
  final String? nfiDivision;
  @JsonKey(name: 'nfi_groupe')
  final String? nfiGroupe;
  @JsonKey(name: 'nfi_classe')
  final String? nfiClasse;
  @JsonKey(name: 'nfi_sous_classe')
  final String? nfiSousClasse;
  static const fromJsonFactory = _$NatinfUpdateFromJson;

  @override
  bool operator ==(Object other) {
    return identical(this, other) ||
        (other is NatinfUpdate &&
            (identical(other.numeroNatinf, numeroNatinf) ||
                const DeepCollectionEquality()
                    .equals(other.numeroNatinf, numeroNatinf)) &&
            (identical(other.changementsCommentaires, changementsCommentaires) ||
                const DeepCollectionEquality().equals(
                    other.changementsCommentaires, changementsCommentaires)) &&
            (identical(other.modesProcesVerbal, modesProcesVerbal) ||
                const DeepCollectionEquality()
                    .equals(other.modesProcesVerbal, modesProcesVerbal)) &&
            (identical(other.sanctionsEncourues, sanctionsEncourues) ||
                const DeepCollectionEquality()
                    .equals(other.sanctionsEncourues, sanctionsEncourues)) &&
            (identical(other.typesAmendeForfaitaire, typesAmendeForfaitaire) ||
                const DeepCollectionEquality().equals(
                    other.typesAmendeForfaitaire, typesAmendeForfaitaire)) &&
            (identical(other.controleAlcoolemie, controleAlcoolemie) ||
                const DeepCollectionEquality()
                    .equals(other.controleAlcoolemie, controleAlcoolemie)) &&
            (identical(other.depistageImpregnationAlcoolique, depistageImpregnationAlcoolique) ||
                const DeepCollectionEquality().equals(
                    other.depistageImpregnationAlcoolique,
                    depistageImpregnationAlcoolique)) &&
            (identical(other.depistageStupefiants, depistageStupefiants) ||
                const DeepCollectionEquality().equals(
                    other.depistageStupefiants, depistageStupefiants)) &&
            (identical(other.retraitPoints, retraitPoints) ||
                const DeepCollectionEquality()
                    .equals(other.retraitPoints, retraitPoints)) &&
            (identical(other.retentionPermisConduire, retentionPermisConduire) ||
                const DeepCollectionEquality().equals(
                    other.retentionPermisConduire, retentionPermisConduire)) &&
            (identical(other.immobilisationVehicule, immobilisationVehicule) ||
                const DeepCollectionEquality().equals(
                    other.immobilisationVehicule, immobilisationVehicule)) &&
            (identical(other.miseEnFourriere, miseEnFourriere) ||
                const DeepCollectionEquality()
                    .equals(other.miseEnFourriere, miseEnFourriere)) &&
            (identical(other.mesuresComplementaires, mesuresComplementaires) ||
                const DeepCollectionEquality().equals(
                    other.mesuresComplementaires, mesuresComplementaires)) &&
            (identical(other.observations, observations) || const DeepCollectionEquality().equals(other.observations, observations)) &&
            (identical(other.nfiSection, nfiSection) || const DeepCollectionEquality().equals(other.nfiSection, nfiSection)) &&
            (identical(other.nfiDivision, nfiDivision) || const DeepCollectionEquality().equals(other.nfiDivision, nfiDivision)) &&
            (identical(other.nfiGroupe, nfiGroupe) || const DeepCollectionEquality().equals(other.nfiGroupe, nfiGroupe)) &&
            (identical(other.nfiClasse, nfiClasse) || const DeepCollectionEquality().equals(other.nfiClasse, nfiClasse)) &&
            (identical(other.nfiSousClasse, nfiSousClasse) || const DeepCollectionEquality().equals(other.nfiSousClasse, nfiSousClasse)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(numeroNatinf) ^
      const DeepCollectionEquality().hash(changementsCommentaires) ^
      const DeepCollectionEquality().hash(modesProcesVerbal) ^
      const DeepCollectionEquality().hash(sanctionsEncourues) ^
      const DeepCollectionEquality().hash(typesAmendeForfaitaire) ^
      const DeepCollectionEquality().hash(controleAlcoolemie) ^
      const DeepCollectionEquality().hash(depistageImpregnationAlcoolique) ^
      const DeepCollectionEquality().hash(depistageStupefiants) ^
      const DeepCollectionEquality().hash(retraitPoints) ^
      const DeepCollectionEquality().hash(retentionPermisConduire) ^
      const DeepCollectionEquality().hash(immobilisationVehicule) ^
      const DeepCollectionEquality().hash(miseEnFourriere) ^
      const DeepCollectionEquality().hash(mesuresComplementaires) ^
      const DeepCollectionEquality().hash(observations) ^
      const DeepCollectionEquality().hash(nfiSection) ^
      const DeepCollectionEquality().hash(nfiDivision) ^
      const DeepCollectionEquality().hash(nfiGroupe) ^
      const DeepCollectionEquality().hash(nfiClasse) ^
      const DeepCollectionEquality().hash(nfiSousClasse) ^
      runtimeType.hashCode;
}

extension $NatinfUpdateExtension on NatinfUpdate {
  NatinfUpdate copyWith(
      {String? numeroNatinf,
      String? changementsCommentaires,
      List<int>? modesProcesVerbal,
      String? sanctionsEncourues,
      int? typesAmendeForfaitaire,
      enums.NatinfUpdateControleAlcoolemie? controleAlcoolemie,
      enums.NatinfUpdateDepistageImpregnationAlcoolique?
          depistageImpregnationAlcoolique,
      enums.NatinfUpdateDepistageStupefiants? depistageStupefiants,
      int? retraitPoints,
      enums.NatinfUpdateRetentionPermisConduire? retentionPermisConduire,
      enums.NatinfUpdateImmobilisationVehicule? immobilisationVehicule,
      enums.NatinfUpdateMiseEnFourriere? miseEnFourriere,
      String? mesuresComplementaires,
      String? observations,
      String? nfiSection,
      String? nfiDivision,
      String? nfiGroupe,
      String? nfiClasse,
      String? nfiSousClasse}) {
    return NatinfUpdate(
        numeroNatinf: numeroNatinf ?? this.numeroNatinf,
        changementsCommentaires:
            changementsCommentaires ?? this.changementsCommentaires,
        modesProcesVerbal: modesProcesVerbal ?? this.modesProcesVerbal,
        sanctionsEncourues: sanctionsEncourues ?? this.sanctionsEncourues,
        typesAmendeForfaitaire:
            typesAmendeForfaitaire ?? this.typesAmendeForfaitaire,
        controleAlcoolemie: controleAlcoolemie ?? this.controleAlcoolemie,
        depistageImpregnationAlcoolique: depistageImpregnationAlcoolique ??
            this.depistageImpregnationAlcoolique,
        depistageStupefiants: depistageStupefiants ?? this.depistageStupefiants,
        retraitPoints: retraitPoints ?? this.retraitPoints,
        retentionPermisConduire:
            retentionPermisConduire ?? this.retentionPermisConduire,
        immobilisationVehicule:
            immobilisationVehicule ?? this.immobilisationVehicule,
        miseEnFourriere: miseEnFourriere ?? this.miseEnFourriere,
        mesuresComplementaires:
            mesuresComplementaires ?? this.mesuresComplementaires,
        observations: observations ?? this.observations,
        nfiSection: nfiSection ?? this.nfiSection,
        nfiDivision: nfiDivision ?? this.nfiDivision,
        nfiGroupe: nfiGroupe ?? this.nfiGroupe,
        nfiClasse: nfiClasse ?? this.nfiClasse,
        nfiSousClasse: nfiSousClasse ?? this.nfiSousClasse);
  }

  NatinfUpdate copyWithWrapped(
      {Wrapped<String>? numeroNatinf,
      Wrapped<String>? changementsCommentaires,
      Wrapped<List<int>?>? modesProcesVerbal,
      Wrapped<String?>? sanctionsEncourues,
      Wrapped<int?>? typesAmendeForfaitaire,
      Wrapped<enums.NatinfUpdateControleAlcoolemie?>? controleAlcoolemie,
      Wrapped<enums.NatinfUpdateDepistageImpregnationAlcoolique?>?
          depistageImpregnationAlcoolique,
      Wrapped<enums.NatinfUpdateDepistageStupefiants?>? depistageStupefiants,
      Wrapped<int?>? retraitPoints,
      Wrapped<enums.NatinfUpdateRetentionPermisConduire?>?
          retentionPermisConduire,
      Wrapped<enums.NatinfUpdateImmobilisationVehicule?>?
          immobilisationVehicule,
      Wrapped<enums.NatinfUpdateMiseEnFourriere?>? miseEnFourriere,
      Wrapped<String?>? mesuresComplementaires,
      Wrapped<String?>? observations,
      Wrapped<String?>? nfiSection,
      Wrapped<String?>? nfiDivision,
      Wrapped<String?>? nfiGroupe,
      Wrapped<String?>? nfiClasse,
      Wrapped<String?>? nfiSousClasse}) {
    return NatinfUpdate(
        numeroNatinf:
            (numeroNatinf != null ? numeroNatinf.value : this.numeroNatinf),
        changementsCommentaires: (changementsCommentaires != null
            ? changementsCommentaires.value
            : this.changementsCommentaires),
        modesProcesVerbal: (modesProcesVerbal != null
            ? modesProcesVerbal.value
            : this.modesProcesVerbal),
        sanctionsEncourues: (sanctionsEncourues != null
            ? sanctionsEncourues.value
            : this.sanctionsEncourues),
        typesAmendeForfaitaire: (typesAmendeForfaitaire != null
            ? typesAmendeForfaitaire.value
            : this.typesAmendeForfaitaire),
        controleAlcoolemie: (controleAlcoolemie != null
            ? controleAlcoolemie.value
            : this.controleAlcoolemie),
        depistageImpregnationAlcoolique:
            (depistageImpregnationAlcoolique != null
                ? depistageImpregnationAlcoolique.value
                : this.depistageImpregnationAlcoolique),
        depistageStupefiants: (depistageStupefiants != null
            ? depistageStupefiants.value
            : this.depistageStupefiants),
        retraitPoints:
            (retraitPoints != null ? retraitPoints.value : this.retraitPoints),
        retentionPermisConduire: (retentionPermisConduire != null
            ? retentionPermisConduire.value
            : this.retentionPermisConduire),
        immobilisationVehicule: (immobilisationVehicule != null
            ? immobilisationVehicule.value
            : this.immobilisationVehicule),
        miseEnFourriere: (miseEnFourriere != null
            ? miseEnFourriere.value
            : this.miseEnFourriere),
        mesuresComplementaires: (mesuresComplementaires != null
            ? mesuresComplementaires.value
            : this.mesuresComplementaires),
        observations:
            (observations != null ? observations.value : this.observations),
        nfiSection: (nfiSection != null ? nfiSection.value : this.nfiSection),
        nfiDivision:
            (nfiDivision != null ? nfiDivision.value : this.nfiDivision),
        nfiGroupe: (nfiGroupe != null ? nfiGroupe.value : this.nfiGroupe),
        nfiClasse: (nfiClasse != null ? nfiClasse.value : this.nfiClasse),
        nfiSousClasse:
            (nfiSousClasse != null ? nfiSousClasse.value : this.nfiSousClasse));
  }
}

@JsonSerializable(explicitToJson: true)
class LegifranceArticleGet$Response {
  const LegifranceArticleGet$Response({
    this.articleText,
  });

  factory LegifranceArticleGet$Response.fromJson(Map<String, dynamic> json) =>
      _$LegifranceArticleGet$ResponseFromJson(json);

  static const toJsonFactory = _$LegifranceArticleGet$ResponseToJson;
  Map<String, dynamic> toJson() => _$LegifranceArticleGet$ResponseToJson(this);

  @JsonKey(name: 'article_text')
  final String? articleText;
  static const fromJsonFactory = _$LegifranceArticleGet$ResponseFromJson;

  @override
  bool operator ==(Object other) {
    return identical(this, other) ||
        (other is LegifranceArticleGet$Response &&
            (identical(other.articleText, articleText) ||
                const DeepCollectionEquality()
                    .equals(other.articleText, articleText)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(articleText) ^ runtimeType.hashCode;
}

extension $LegifranceArticleGet$ResponseExtension
    on LegifranceArticleGet$Response {
  LegifranceArticleGet$Response copyWith({String? articleText}) {
    return LegifranceArticleGet$Response(
        articleText: articleText ?? this.articleText);
  }

  LegifranceArticleGet$Response copyWithWrapped(
      {Wrapped<String?>? articleText}) {
    return LegifranceArticleGet$Response(
        articleText:
            (articleText != null ? articleText.value : this.articleText));
  }
}

@JsonSerializable(explicitToJson: true)
class LegifranceIdGet$Response {
  const LegifranceIdGet$Response({
    this.articleId,
  });

  factory LegifranceIdGet$Response.fromJson(Map<String, dynamic> json) =>
      _$LegifranceIdGet$ResponseFromJson(json);

  static const toJsonFactory = _$LegifranceIdGet$ResponseToJson;
  Map<String, dynamic> toJson() => _$LegifranceIdGet$ResponseToJson(this);

  @JsonKey(name: 'article_id')
  final String? articleId;
  static const fromJsonFactory = _$LegifranceIdGet$ResponseFromJson;

  @override
  bool operator ==(Object other) {
    return identical(this, other) ||
        (other is LegifranceIdGet$Response &&
            (identical(other.articleId, articleId) ||
                const DeepCollectionEquality()
                    .equals(other.articleId, articleId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(articleId) ^ runtimeType.hashCode;
}

extension $LegifranceIdGet$ResponseExtension on LegifranceIdGet$Response {
  LegifranceIdGet$Response copyWith({String? articleId}) {
    return LegifranceIdGet$Response(articleId: articleId ?? this.articleId);
  }

  LegifranceIdGet$Response copyWithWrapped({Wrapped<String?>? articleId}) {
    return LegifranceIdGet$Response(
        articleId: (articleId != null ? articleId.value : this.articleId));
  }
}

@JsonSerializable(explicitToJson: true)
class NatinfoTexteTypeLibelleGet$Response {
  const NatinfoTexteTypeLibelleGet$Response({
    this.abreviation,
    this.libelle,
    this.libelleLegifranceApi,
  });

  factory NatinfoTexteTypeLibelleGet$Response.fromJson(
          Map<String, dynamic> json) =>
      _$NatinfoTexteTypeLibelleGet$ResponseFromJson(json);

  static const toJsonFactory = _$NatinfoTexteTypeLibelleGet$ResponseToJson;
  Map<String, dynamic> toJson() =>
      _$NatinfoTexteTypeLibelleGet$ResponseToJson(this);

  @JsonKey(name: 'abreviation')
  final String? abreviation;
  @JsonKey(name: 'libelle')
  final String? libelle;
  @JsonKey(name: 'libelle_legifrance_api')
  final String? libelleLegifranceApi;
  static const fromJsonFactory = _$NatinfoTexteTypeLibelleGet$ResponseFromJson;

  @override
  bool operator ==(Object other) {
    return identical(this, other) ||
        (other is NatinfoTexteTypeLibelleGet$Response &&
            (identical(other.abreviation, abreviation) ||
                const DeepCollectionEquality()
                    .equals(other.abreviation, abreviation)) &&
            (identical(other.libelle, libelle) ||
                const DeepCollectionEquality()
                    .equals(other.libelle, libelle)) &&
            (identical(other.libelleLegifranceApi, libelleLegifranceApi) ||
                const DeepCollectionEquality()
                    .equals(other.libelleLegifranceApi, libelleLegifranceApi)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(abreviation) ^
      const DeepCollectionEquality().hash(libelle) ^
      const DeepCollectionEquality().hash(libelleLegifranceApi) ^
      runtimeType.hashCode;
}

extension $NatinfoTexteTypeLibelleGet$ResponseExtension
    on NatinfoTexteTypeLibelleGet$Response {
  NatinfoTexteTypeLibelleGet$Response copyWith(
      {String? abreviation, String? libelle, String? libelleLegifranceApi}) {
    return NatinfoTexteTypeLibelleGet$Response(
        abreviation: abreviation ?? this.abreviation,
        libelle: libelle ?? this.libelle,
        libelleLegifranceApi:
            libelleLegifranceApi ?? this.libelleLegifranceApi);
  }

  NatinfoTexteTypeLibelleGet$Response copyWithWrapped(
      {Wrapped<String?>? abreviation,
      Wrapped<String?>? libelle,
      Wrapped<String?>? libelleLegifranceApi}) {
    return NatinfoTexteTypeLibelleGet$Response(
        abreviation:
            (abreviation != null ? abreviation.value : this.abreviation),
        libelle: (libelle != null ? libelle.value : this.libelle),
        libelleLegifranceApi: (libelleLegifranceApi != null
            ? libelleLegifranceApi.value
            : this.libelleLegifranceApi));
  }
}

String? natinfControleAlcoolemieNullableToJson(
    enums.NatinfControleAlcoolemie? natinfControleAlcoolemie) {
  return natinfControleAlcoolemie?.value;
}

String? natinfControleAlcoolemieToJson(
    enums.NatinfControleAlcoolemie natinfControleAlcoolemie) {
  return natinfControleAlcoolemie.value;
}

enums.NatinfControleAlcoolemie natinfControleAlcoolemieFromJson(
  Object? natinfControleAlcoolemie, [
  enums.NatinfControleAlcoolemie? defaultValue,
]) {
  return enums.NatinfControleAlcoolemie.values
          .firstWhereOrNull((e) => e.value == natinfControleAlcoolemie) ??
      defaultValue ??
      enums.NatinfControleAlcoolemie.swaggerGeneratedUnknown;
}

enums.NatinfControleAlcoolemie? natinfControleAlcoolemieNullableFromJson(
  Object? natinfControleAlcoolemie, [
  enums.NatinfControleAlcoolemie? defaultValue,
]) {
  if (natinfControleAlcoolemie == null) {
    return null;
  }
  return enums.NatinfControleAlcoolemie.values
          .firstWhereOrNull((e) => e.value == natinfControleAlcoolemie) ??
      defaultValue;
}

String natinfControleAlcoolemieExplodedListToJson(
    List<enums.NatinfControleAlcoolemie>? natinfControleAlcoolemie) {
  return natinfControleAlcoolemie?.map((e) => e.value!).join(',') ?? '';
}

List<String> natinfControleAlcoolemieListToJson(
    List<enums.NatinfControleAlcoolemie>? natinfControleAlcoolemie) {
  if (natinfControleAlcoolemie == null) {
    return [];
  }

  return natinfControleAlcoolemie.map((e) => e.value!).toList();
}

List<enums.NatinfControleAlcoolemie> natinfControleAlcoolemieListFromJson(
  List? natinfControleAlcoolemie, [
  List<enums.NatinfControleAlcoolemie>? defaultValue,
]) {
  if (natinfControleAlcoolemie == null) {
    return defaultValue ?? [];
  }

  return natinfControleAlcoolemie
      .map((e) => natinfControleAlcoolemieFromJson(e.toString()))
      .toList();
}

List<enums.NatinfControleAlcoolemie>?
    natinfControleAlcoolemieNullableListFromJson(
  List? natinfControleAlcoolemie, [
  List<enums.NatinfControleAlcoolemie>? defaultValue,
]) {
  if (natinfControleAlcoolemie == null) {
    return defaultValue;
  }

  return natinfControleAlcoolemie
      .map((e) => natinfControleAlcoolemieFromJson(e.toString()))
      .toList();
}

String? natinfDepistageImpregnationAlcooliqueNullableToJson(
    enums.NatinfDepistageImpregnationAlcoolique?
        natinfDepistageImpregnationAlcoolique) {
  return natinfDepistageImpregnationAlcoolique?.value;
}

String? natinfDepistageImpregnationAlcooliqueToJson(
    enums.NatinfDepistageImpregnationAlcoolique
        natinfDepistageImpregnationAlcoolique) {
  return natinfDepistageImpregnationAlcoolique.value;
}

enums.NatinfDepistageImpregnationAlcoolique
    natinfDepistageImpregnationAlcooliqueFromJson(
  Object? natinfDepistageImpregnationAlcoolique, [
  enums.NatinfDepistageImpregnationAlcoolique? defaultValue,
]) {
  return enums.NatinfDepistageImpregnationAlcoolique.values.firstWhereOrNull(
          (e) => e.value == natinfDepistageImpregnationAlcoolique) ??
      defaultValue ??
      enums.NatinfDepistageImpregnationAlcoolique.swaggerGeneratedUnknown;
}

enums.NatinfDepistageImpregnationAlcoolique?
    natinfDepistageImpregnationAlcooliqueNullableFromJson(
  Object? natinfDepistageImpregnationAlcoolique, [
  enums.NatinfDepistageImpregnationAlcoolique? defaultValue,
]) {
  if (natinfDepistageImpregnationAlcoolique == null) {
    return null;
  }
  return enums.NatinfDepistageImpregnationAlcoolique.values.firstWhereOrNull(
          (e) => e.value == natinfDepistageImpregnationAlcoolique) ??
      defaultValue;
}

String natinfDepistageImpregnationAlcooliqueExplodedListToJson(
    List<enums.NatinfDepistageImpregnationAlcoolique>?
        natinfDepistageImpregnationAlcoolique) {
  return natinfDepistageImpregnationAlcoolique
          ?.map((e) => e.value!)
          .join(',') ??
      '';
}

List<String> natinfDepistageImpregnationAlcooliqueListToJson(
    List<enums.NatinfDepistageImpregnationAlcoolique>?
        natinfDepistageImpregnationAlcoolique) {
  if (natinfDepistageImpregnationAlcoolique == null) {
    return [];
  }

  return natinfDepistageImpregnationAlcoolique.map((e) => e.value!).toList();
}

List<enums.NatinfDepistageImpregnationAlcoolique>
    natinfDepistageImpregnationAlcooliqueListFromJson(
  List? natinfDepistageImpregnationAlcoolique, [
  List<enums.NatinfDepistageImpregnationAlcoolique>? defaultValue,
]) {
  if (natinfDepistageImpregnationAlcoolique == null) {
    return defaultValue ?? [];
  }

  return natinfDepistageImpregnationAlcoolique
      .map((e) => natinfDepistageImpregnationAlcooliqueFromJson(e.toString()))
      .toList();
}

List<enums.NatinfDepistageImpregnationAlcoolique>?
    natinfDepistageImpregnationAlcooliqueNullableListFromJson(
  List? natinfDepistageImpregnationAlcoolique, [
  List<enums.NatinfDepistageImpregnationAlcoolique>? defaultValue,
]) {
  if (natinfDepistageImpregnationAlcoolique == null) {
    return defaultValue;
  }

  return natinfDepistageImpregnationAlcoolique
      .map((e) => natinfDepistageImpregnationAlcooliqueFromJson(e.toString()))
      .toList();
}

String? natinfDepistageStupefiantsNullableToJson(
    enums.NatinfDepistageStupefiants? natinfDepistageStupefiants) {
  return natinfDepistageStupefiants?.value;
}

String? natinfDepistageStupefiantsToJson(
    enums.NatinfDepistageStupefiants natinfDepistageStupefiants) {
  return natinfDepistageStupefiants.value;
}

enums.NatinfDepistageStupefiants natinfDepistageStupefiantsFromJson(
  Object? natinfDepistageStupefiants, [
  enums.NatinfDepistageStupefiants? defaultValue,
]) {
  return enums.NatinfDepistageStupefiants.values
          .firstWhereOrNull((e) => e.value == natinfDepistageStupefiants) ??
      defaultValue ??
      enums.NatinfDepistageStupefiants.swaggerGeneratedUnknown;
}

enums.NatinfDepistageStupefiants? natinfDepistageStupefiantsNullableFromJson(
  Object? natinfDepistageStupefiants, [
  enums.NatinfDepistageStupefiants? defaultValue,
]) {
  if (natinfDepistageStupefiants == null) {
    return null;
  }
  return enums.NatinfDepistageStupefiants.values
          .firstWhereOrNull((e) => e.value == natinfDepistageStupefiants) ??
      defaultValue;
}

String natinfDepistageStupefiantsExplodedListToJson(
    List<enums.NatinfDepistageStupefiants>? natinfDepistageStupefiants) {
  return natinfDepistageStupefiants?.map((e) => e.value!).join(',') ?? '';
}

List<String> natinfDepistageStupefiantsListToJson(
    List<enums.NatinfDepistageStupefiants>? natinfDepistageStupefiants) {
  if (natinfDepistageStupefiants == null) {
    return [];
  }

  return natinfDepistageStupefiants.map((e) => e.value!).toList();
}

List<enums.NatinfDepistageStupefiants> natinfDepistageStupefiantsListFromJson(
  List? natinfDepistageStupefiants, [
  List<enums.NatinfDepistageStupefiants>? defaultValue,
]) {
  if (natinfDepistageStupefiants == null) {
    return defaultValue ?? [];
  }

  return natinfDepistageStupefiants
      .map((e) => natinfDepistageStupefiantsFromJson(e.toString()))
      .toList();
}

List<enums.NatinfDepistageStupefiants>?
    natinfDepistageStupefiantsNullableListFromJson(
  List? natinfDepistageStupefiants, [
  List<enums.NatinfDepistageStupefiants>? defaultValue,
]) {
  if (natinfDepistageStupefiants == null) {
    return defaultValue;
  }

  return natinfDepistageStupefiants
      .map((e) => natinfDepistageStupefiantsFromJson(e.toString()))
      .toList();
}

int? natinfRetraitPointsNullableToJson(
    enums.NatinfRetraitPoints? natinfRetraitPoints) {
  return natinfRetraitPoints?.value;
}

int? natinfRetraitPointsToJson(enums.NatinfRetraitPoints natinfRetraitPoints) {
  return natinfRetraitPoints.value;
}

enums.NatinfRetraitPoints natinfRetraitPointsFromJson(
  Object? natinfRetraitPoints, [
  enums.NatinfRetraitPoints? defaultValue,
]) {
  return enums.NatinfRetraitPoints.values
          .firstWhereOrNull((e) => e.value == natinfRetraitPoints) ??
      defaultValue ??
      enums.NatinfRetraitPoints.swaggerGeneratedUnknown;
}

enums.NatinfRetraitPoints? natinfRetraitPointsNullableFromJson(
  Object? natinfRetraitPoints, [
  enums.NatinfRetraitPoints? defaultValue,
]) {
  if (natinfRetraitPoints == null) {
    return null;
  }
  return enums.NatinfRetraitPoints.values
          .firstWhereOrNull((e) => e.value == natinfRetraitPoints) ??
      defaultValue;
}

String natinfRetraitPointsExplodedListToJson(
    List<enums.NatinfRetraitPoints>? natinfRetraitPoints) {
  return natinfRetraitPoints?.map((e) => e.value!).join(',') ?? '';
}

List<int> natinfRetraitPointsListToJson(
    List<enums.NatinfRetraitPoints>? natinfRetraitPoints) {
  if (natinfRetraitPoints == null) {
    return [];
  }

  return natinfRetraitPoints.map((e) => e.value!).toList();
}

List<enums.NatinfRetraitPoints> natinfRetraitPointsListFromJson(
  List? natinfRetraitPoints, [
  List<enums.NatinfRetraitPoints>? defaultValue,
]) {
  if (natinfRetraitPoints == null) {
    return defaultValue ?? [];
  }

  return natinfRetraitPoints
      .map((e) => natinfRetraitPointsFromJson(e.toString()))
      .toList();
}

List<enums.NatinfRetraitPoints>? natinfRetraitPointsNullableListFromJson(
  List? natinfRetraitPoints, [
  List<enums.NatinfRetraitPoints>? defaultValue,
]) {
  if (natinfRetraitPoints == null) {
    return defaultValue;
  }

  return natinfRetraitPoints
      .map((e) => natinfRetraitPointsFromJson(e.toString()))
      .toList();
}

String? natinfRetentionPermisConduireNullableToJson(
    enums.NatinfRetentionPermisConduire? natinfRetentionPermisConduire) {
  return natinfRetentionPermisConduire?.value;
}

String? natinfRetentionPermisConduireToJson(
    enums.NatinfRetentionPermisConduire natinfRetentionPermisConduire) {
  return natinfRetentionPermisConduire.value;
}

enums.NatinfRetentionPermisConduire natinfRetentionPermisConduireFromJson(
  Object? natinfRetentionPermisConduire, [
  enums.NatinfRetentionPermisConduire? defaultValue,
]) {
  return enums.NatinfRetentionPermisConduire.values
          .firstWhereOrNull((e) => e.value == natinfRetentionPermisConduire) ??
      defaultValue ??
      enums.NatinfRetentionPermisConduire.swaggerGeneratedUnknown;
}

enums.NatinfRetentionPermisConduire?
    natinfRetentionPermisConduireNullableFromJson(
  Object? natinfRetentionPermisConduire, [
  enums.NatinfRetentionPermisConduire? defaultValue,
]) {
  if (natinfRetentionPermisConduire == null) {
    return null;
  }
  return enums.NatinfRetentionPermisConduire.values
          .firstWhereOrNull((e) => e.value == natinfRetentionPermisConduire) ??
      defaultValue;
}

String natinfRetentionPermisConduireExplodedListToJson(
    List<enums.NatinfRetentionPermisConduire>? natinfRetentionPermisConduire) {
  return natinfRetentionPermisConduire?.map((e) => e.value!).join(',') ?? '';
}

List<String> natinfRetentionPermisConduireListToJson(
    List<enums.NatinfRetentionPermisConduire>? natinfRetentionPermisConduire) {
  if (natinfRetentionPermisConduire == null) {
    return [];
  }

  return natinfRetentionPermisConduire.map((e) => e.value!).toList();
}

List<enums.NatinfRetentionPermisConduire>
    natinfRetentionPermisConduireListFromJson(
  List? natinfRetentionPermisConduire, [
  List<enums.NatinfRetentionPermisConduire>? defaultValue,
]) {
  if (natinfRetentionPermisConduire == null) {
    return defaultValue ?? [];
  }

  return natinfRetentionPermisConduire
      .map((e) => natinfRetentionPermisConduireFromJson(e.toString()))
      .toList();
}

List<enums.NatinfRetentionPermisConduire>?
    natinfRetentionPermisConduireNullableListFromJson(
  List? natinfRetentionPermisConduire, [
  List<enums.NatinfRetentionPermisConduire>? defaultValue,
]) {
  if (natinfRetentionPermisConduire == null) {
    return defaultValue;
  }

  return natinfRetentionPermisConduire
      .map((e) => natinfRetentionPermisConduireFromJson(e.toString()))
      .toList();
}

String? natinfImmobilisationVehiculeNullableToJson(
    enums.NatinfImmobilisationVehicule? natinfImmobilisationVehicule) {
  return natinfImmobilisationVehicule?.value;
}

String? natinfImmobilisationVehiculeToJson(
    enums.NatinfImmobilisationVehicule natinfImmobilisationVehicule) {
  return natinfImmobilisationVehicule.value;
}

enums.NatinfImmobilisationVehicule natinfImmobilisationVehiculeFromJson(
  Object? natinfImmobilisationVehicule, [
  enums.NatinfImmobilisationVehicule? defaultValue,
]) {
  return enums.NatinfImmobilisationVehicule.values
          .firstWhereOrNull((e) => e.value == natinfImmobilisationVehicule) ??
      defaultValue ??
      enums.NatinfImmobilisationVehicule.swaggerGeneratedUnknown;
}

enums.NatinfImmobilisationVehicule?
    natinfImmobilisationVehiculeNullableFromJson(
  Object? natinfImmobilisationVehicule, [
  enums.NatinfImmobilisationVehicule? defaultValue,
]) {
  if (natinfImmobilisationVehicule == null) {
    return null;
  }
  return enums.NatinfImmobilisationVehicule.values
          .firstWhereOrNull((e) => e.value == natinfImmobilisationVehicule) ??
      defaultValue;
}

String natinfImmobilisationVehiculeExplodedListToJson(
    List<enums.NatinfImmobilisationVehicule>? natinfImmobilisationVehicule) {
  return natinfImmobilisationVehicule?.map((e) => e.value!).join(',') ?? '';
}

List<String> natinfImmobilisationVehiculeListToJson(
    List<enums.NatinfImmobilisationVehicule>? natinfImmobilisationVehicule) {
  if (natinfImmobilisationVehicule == null) {
    return [];
  }

  return natinfImmobilisationVehicule.map((e) => e.value!).toList();
}

List<enums.NatinfImmobilisationVehicule>
    natinfImmobilisationVehiculeListFromJson(
  List? natinfImmobilisationVehicule, [
  List<enums.NatinfImmobilisationVehicule>? defaultValue,
]) {
  if (natinfImmobilisationVehicule == null) {
    return defaultValue ?? [];
  }

  return natinfImmobilisationVehicule
      .map((e) => natinfImmobilisationVehiculeFromJson(e.toString()))
      .toList();
}

List<enums.NatinfImmobilisationVehicule>?
    natinfImmobilisationVehiculeNullableListFromJson(
  List? natinfImmobilisationVehicule, [
  List<enums.NatinfImmobilisationVehicule>? defaultValue,
]) {
  if (natinfImmobilisationVehicule == null) {
    return defaultValue;
  }

  return natinfImmobilisationVehicule
      .map((e) => natinfImmobilisationVehiculeFromJson(e.toString()))
      .toList();
}

String? natinfMiseEnFourriereNullableToJson(
    enums.NatinfMiseEnFourriere? natinfMiseEnFourriere) {
  return natinfMiseEnFourriere?.value;
}

String? natinfMiseEnFourriereToJson(
    enums.NatinfMiseEnFourriere natinfMiseEnFourriere) {
  return natinfMiseEnFourriere.value;
}

enums.NatinfMiseEnFourriere natinfMiseEnFourriereFromJson(
  Object? natinfMiseEnFourriere, [
  enums.NatinfMiseEnFourriere? defaultValue,
]) {
  return enums.NatinfMiseEnFourriere.values
          .firstWhereOrNull((e) => e.value == natinfMiseEnFourriere) ??
      defaultValue ??
      enums.NatinfMiseEnFourriere.swaggerGeneratedUnknown;
}

enums.NatinfMiseEnFourriere? natinfMiseEnFourriereNullableFromJson(
  Object? natinfMiseEnFourriere, [
  enums.NatinfMiseEnFourriere? defaultValue,
]) {
  if (natinfMiseEnFourriere == null) {
    return null;
  }
  return enums.NatinfMiseEnFourriere.values
          .firstWhereOrNull((e) => e.value == natinfMiseEnFourriere) ??
      defaultValue;
}

String natinfMiseEnFourriereExplodedListToJson(
    List<enums.NatinfMiseEnFourriere>? natinfMiseEnFourriere) {
  return natinfMiseEnFourriere?.map((e) => e.value!).join(',') ?? '';
}

List<String> natinfMiseEnFourriereListToJson(
    List<enums.NatinfMiseEnFourriere>? natinfMiseEnFourriere) {
  if (natinfMiseEnFourriere == null) {
    return [];
  }

  return natinfMiseEnFourriere.map((e) => e.value!).toList();
}

List<enums.NatinfMiseEnFourriere> natinfMiseEnFourriereListFromJson(
  List? natinfMiseEnFourriere, [
  List<enums.NatinfMiseEnFourriere>? defaultValue,
]) {
  if (natinfMiseEnFourriere == null) {
    return defaultValue ?? [];
  }

  return natinfMiseEnFourriere
      .map((e) => natinfMiseEnFourriereFromJson(e.toString()))
      .toList();
}

List<enums.NatinfMiseEnFourriere>? natinfMiseEnFourriereNullableListFromJson(
  List? natinfMiseEnFourriere, [
  List<enums.NatinfMiseEnFourriere>? defaultValue,
]) {
  if (natinfMiseEnFourriere == null) {
    return defaultValue;
  }

  return natinfMiseEnFourriere
      .map((e) => natinfMiseEnFourriereFromJson(e.toString()))
      .toList();
}

String? natinfUpdateControleAlcoolemieNullableToJson(
    enums.NatinfUpdateControleAlcoolemie? natinfUpdateControleAlcoolemie) {
  return natinfUpdateControleAlcoolemie?.value;
}

String? natinfUpdateControleAlcoolemieToJson(
    enums.NatinfUpdateControleAlcoolemie natinfUpdateControleAlcoolemie) {
  return natinfUpdateControleAlcoolemie.value;
}

enums.NatinfUpdateControleAlcoolemie natinfUpdateControleAlcoolemieFromJson(
  Object? natinfUpdateControleAlcoolemie, [
  enums.NatinfUpdateControleAlcoolemie? defaultValue,
]) {
  return enums.NatinfUpdateControleAlcoolemie.values
          .firstWhereOrNull((e) => e.value == natinfUpdateControleAlcoolemie) ??
      defaultValue ??
      enums.NatinfUpdateControleAlcoolemie.swaggerGeneratedUnknown;
}

enums.NatinfUpdateControleAlcoolemie?
    natinfUpdateControleAlcoolemieNullableFromJson(
  Object? natinfUpdateControleAlcoolemie, [
  enums.NatinfUpdateControleAlcoolemie? defaultValue,
]) {
  if (natinfUpdateControleAlcoolemie == null) {
    return null;
  }
  return enums.NatinfUpdateControleAlcoolemie.values
          .firstWhereOrNull((e) => e.value == natinfUpdateControleAlcoolemie) ??
      defaultValue;
}

String natinfUpdateControleAlcoolemieExplodedListToJson(
    List<enums.NatinfUpdateControleAlcoolemie>?
        natinfUpdateControleAlcoolemie) {
  return natinfUpdateControleAlcoolemie?.map((e) => e.value!).join(',') ?? '';
}

List<String> natinfUpdateControleAlcoolemieListToJson(
    List<enums.NatinfUpdateControleAlcoolemie>?
        natinfUpdateControleAlcoolemie) {
  if (natinfUpdateControleAlcoolemie == null) {
    return [];
  }

  return natinfUpdateControleAlcoolemie.map((e) => e.value!).toList();
}

List<enums.NatinfUpdateControleAlcoolemie>
    natinfUpdateControleAlcoolemieListFromJson(
  List? natinfUpdateControleAlcoolemie, [
  List<enums.NatinfUpdateControleAlcoolemie>? defaultValue,
]) {
  if (natinfUpdateControleAlcoolemie == null) {
    return defaultValue ?? [];
  }

  return natinfUpdateControleAlcoolemie
      .map((e) => natinfUpdateControleAlcoolemieFromJson(e.toString()))
      .toList();
}

List<enums.NatinfUpdateControleAlcoolemie>?
    natinfUpdateControleAlcoolemieNullableListFromJson(
  List? natinfUpdateControleAlcoolemie, [
  List<enums.NatinfUpdateControleAlcoolemie>? defaultValue,
]) {
  if (natinfUpdateControleAlcoolemie == null) {
    return defaultValue;
  }

  return natinfUpdateControleAlcoolemie
      .map((e) => natinfUpdateControleAlcoolemieFromJson(e.toString()))
      .toList();
}

String? natinfUpdateDepistageImpregnationAlcooliqueNullableToJson(
    enums.NatinfUpdateDepistageImpregnationAlcoolique?
        natinfUpdateDepistageImpregnationAlcoolique) {
  return natinfUpdateDepistageImpregnationAlcoolique?.value;
}

String? natinfUpdateDepistageImpregnationAlcooliqueToJson(
    enums.NatinfUpdateDepistageImpregnationAlcoolique
        natinfUpdateDepistageImpregnationAlcoolique) {
  return natinfUpdateDepistageImpregnationAlcoolique.value;
}

enums.NatinfUpdateDepistageImpregnationAlcoolique
    natinfUpdateDepistageImpregnationAlcooliqueFromJson(
  Object? natinfUpdateDepistageImpregnationAlcoolique, [
  enums.NatinfUpdateDepistageImpregnationAlcoolique? defaultValue,
]) {
  return enums.NatinfUpdateDepistageImpregnationAlcoolique.values
          .firstWhereOrNull(
              (e) => e.value == natinfUpdateDepistageImpregnationAlcoolique) ??
      defaultValue ??
      enums.NatinfUpdateDepistageImpregnationAlcoolique.swaggerGeneratedUnknown;
}

enums.NatinfUpdateDepistageImpregnationAlcoolique?
    natinfUpdateDepistageImpregnationAlcooliqueNullableFromJson(
  Object? natinfUpdateDepistageImpregnationAlcoolique, [
  enums.NatinfUpdateDepistageImpregnationAlcoolique? defaultValue,
]) {
  if (natinfUpdateDepistageImpregnationAlcoolique == null) {
    return null;
  }
  return enums.NatinfUpdateDepistageImpregnationAlcoolique.values
          .firstWhereOrNull(
              (e) => e.value == natinfUpdateDepistageImpregnationAlcoolique) ??
      defaultValue;
}

String natinfUpdateDepistageImpregnationAlcooliqueExplodedListToJson(
    List<enums.NatinfUpdateDepistageImpregnationAlcoolique>?
        natinfUpdateDepistageImpregnationAlcoolique) {
  return natinfUpdateDepistageImpregnationAlcoolique
          ?.map((e) => e.value!)
          .join(',') ??
      '';
}

List<String> natinfUpdateDepistageImpregnationAlcooliqueListToJson(
    List<enums.NatinfUpdateDepistageImpregnationAlcoolique>?
        natinfUpdateDepistageImpregnationAlcoolique) {
  if (natinfUpdateDepistageImpregnationAlcoolique == null) {
    return [];
  }

  return natinfUpdateDepistageImpregnationAlcoolique
      .map((e) => e.value!)
      .toList();
}

List<enums.NatinfUpdateDepistageImpregnationAlcoolique>
    natinfUpdateDepistageImpregnationAlcooliqueListFromJson(
  List? natinfUpdateDepistageImpregnationAlcoolique, [
  List<enums.NatinfUpdateDepistageImpregnationAlcoolique>? defaultValue,
]) {
  if (natinfUpdateDepistageImpregnationAlcoolique == null) {
    return defaultValue ?? [];
  }

  return natinfUpdateDepistageImpregnationAlcoolique
      .map((e) =>
          natinfUpdateDepistageImpregnationAlcooliqueFromJson(e.toString()))
      .toList();
}

List<enums.NatinfUpdateDepistageImpregnationAlcoolique>?
    natinfUpdateDepistageImpregnationAlcooliqueNullableListFromJson(
  List? natinfUpdateDepistageImpregnationAlcoolique, [
  List<enums.NatinfUpdateDepistageImpregnationAlcoolique>? defaultValue,
]) {
  if (natinfUpdateDepistageImpregnationAlcoolique == null) {
    return defaultValue;
  }

  return natinfUpdateDepistageImpregnationAlcoolique
      .map((e) =>
          natinfUpdateDepistageImpregnationAlcooliqueFromJson(e.toString()))
      .toList();
}

String? natinfUpdateDepistageStupefiantsNullableToJson(
    enums.NatinfUpdateDepistageStupefiants? natinfUpdateDepistageStupefiants) {
  return natinfUpdateDepistageStupefiants?.value;
}

String? natinfUpdateDepistageStupefiantsToJson(
    enums.NatinfUpdateDepistageStupefiants natinfUpdateDepistageStupefiants) {
  return natinfUpdateDepistageStupefiants.value;
}

enums.NatinfUpdateDepistageStupefiants natinfUpdateDepistageStupefiantsFromJson(
  Object? natinfUpdateDepistageStupefiants, [
  enums.NatinfUpdateDepistageStupefiants? defaultValue,
]) {
  return enums.NatinfUpdateDepistageStupefiants.values.firstWhereOrNull(
          (e) => e.value == natinfUpdateDepistageStupefiants) ??
      defaultValue ??
      enums.NatinfUpdateDepistageStupefiants.swaggerGeneratedUnknown;
}

enums.NatinfUpdateDepistageStupefiants?
    natinfUpdateDepistageStupefiantsNullableFromJson(
  Object? natinfUpdateDepistageStupefiants, [
  enums.NatinfUpdateDepistageStupefiants? defaultValue,
]) {
  if (natinfUpdateDepistageStupefiants == null) {
    return null;
  }
  return enums.NatinfUpdateDepistageStupefiants.values.firstWhereOrNull(
          (e) => e.value == natinfUpdateDepistageStupefiants) ??
      defaultValue;
}

String natinfUpdateDepistageStupefiantsExplodedListToJson(
    List<enums.NatinfUpdateDepistageStupefiants>?
        natinfUpdateDepistageStupefiants) {
  return natinfUpdateDepistageStupefiants?.map((e) => e.value!).join(',') ?? '';
}

List<String> natinfUpdateDepistageStupefiantsListToJson(
    List<enums.NatinfUpdateDepistageStupefiants>?
        natinfUpdateDepistageStupefiants) {
  if (natinfUpdateDepistageStupefiants == null) {
    return [];
  }

  return natinfUpdateDepistageStupefiants.map((e) => e.value!).toList();
}

List<enums.NatinfUpdateDepistageStupefiants>
    natinfUpdateDepistageStupefiantsListFromJson(
  List? natinfUpdateDepistageStupefiants, [
  List<enums.NatinfUpdateDepistageStupefiants>? defaultValue,
]) {
  if (natinfUpdateDepistageStupefiants == null) {
    return defaultValue ?? [];
  }

  return natinfUpdateDepistageStupefiants
      .map((e) => natinfUpdateDepistageStupefiantsFromJson(e.toString()))
      .toList();
}

List<enums.NatinfUpdateDepistageStupefiants>?
    natinfUpdateDepistageStupefiantsNullableListFromJson(
  List? natinfUpdateDepistageStupefiants, [
  List<enums.NatinfUpdateDepistageStupefiants>? defaultValue,
]) {
  if (natinfUpdateDepistageStupefiants == null) {
    return defaultValue;
  }

  return natinfUpdateDepistageStupefiants
      .map((e) => natinfUpdateDepistageStupefiantsFromJson(e.toString()))
      .toList();
}

int? natinfUpdateRetraitPointsNullableToJson(
    enums.NatinfUpdateRetraitPoints? natinfUpdateRetraitPoints) {
  return natinfUpdateRetraitPoints?.value;
}

int? natinfUpdateRetraitPointsToJson(
    enums.NatinfUpdateRetraitPoints natinfUpdateRetraitPoints) {
  return natinfUpdateRetraitPoints.value;
}

enums.NatinfUpdateRetraitPoints natinfUpdateRetraitPointsFromJson(
  Object? natinfUpdateRetraitPoints, [
  enums.NatinfUpdateRetraitPoints? defaultValue,
]) {
  return enums.NatinfUpdateRetraitPoints.values
          .firstWhereOrNull((e) => e.value == natinfUpdateRetraitPoints) ??
      defaultValue ??
      enums.NatinfUpdateRetraitPoints.swaggerGeneratedUnknown;
}

enums.NatinfUpdateRetraitPoints? natinfUpdateRetraitPointsNullableFromJson(
  Object? natinfUpdateRetraitPoints, [
  enums.NatinfUpdateRetraitPoints? defaultValue,
]) {
  if (natinfUpdateRetraitPoints == null) {
    return null;
  }
  return enums.NatinfUpdateRetraitPoints.values
          .firstWhereOrNull((e) => e.value == natinfUpdateRetraitPoints) ??
      defaultValue;
}

String natinfUpdateRetraitPointsExplodedListToJson(
    List<enums.NatinfUpdateRetraitPoints>? natinfUpdateRetraitPoints) {
  return natinfUpdateRetraitPoints?.map((e) => e.value!).join(',') ?? '';
}

List<int> natinfUpdateRetraitPointsListToJson(
    List<enums.NatinfUpdateRetraitPoints>? natinfUpdateRetraitPoints) {
  if (natinfUpdateRetraitPoints == null) {
    return [];
  }

  return natinfUpdateRetraitPoints.map((e) => e.value!).toList();
}

List<enums.NatinfUpdateRetraitPoints> natinfUpdateRetraitPointsListFromJson(
  List? natinfUpdateRetraitPoints, [
  List<enums.NatinfUpdateRetraitPoints>? defaultValue,
]) {
  if (natinfUpdateRetraitPoints == null) {
    return defaultValue ?? [];
  }

  return natinfUpdateRetraitPoints
      .map((e) => natinfUpdateRetraitPointsFromJson(e.toString()))
      .toList();
}

List<enums.NatinfUpdateRetraitPoints>?
    natinfUpdateRetraitPointsNullableListFromJson(
  List? natinfUpdateRetraitPoints, [
  List<enums.NatinfUpdateRetraitPoints>? defaultValue,
]) {
  if (natinfUpdateRetraitPoints == null) {
    return defaultValue;
  }

  return natinfUpdateRetraitPoints
      .map((e) => natinfUpdateRetraitPointsFromJson(e.toString()))
      .toList();
}

String? natinfUpdateRetentionPermisConduireNullableToJson(
    enums.NatinfUpdateRetentionPermisConduire?
        natinfUpdateRetentionPermisConduire) {
  return natinfUpdateRetentionPermisConduire?.value;
}

String? natinfUpdateRetentionPermisConduireToJson(
    enums.NatinfUpdateRetentionPermisConduire
        natinfUpdateRetentionPermisConduire) {
  return natinfUpdateRetentionPermisConduire.value;
}

enums.NatinfUpdateRetentionPermisConduire
    natinfUpdateRetentionPermisConduireFromJson(
  Object? natinfUpdateRetentionPermisConduire, [
  enums.NatinfUpdateRetentionPermisConduire? defaultValue,
]) {
  return enums.NatinfUpdateRetentionPermisConduire.values.firstWhereOrNull(
          (e) => e.value == natinfUpdateRetentionPermisConduire) ??
      defaultValue ??
      enums.NatinfUpdateRetentionPermisConduire.swaggerGeneratedUnknown;
}

enums.NatinfUpdateRetentionPermisConduire?
    natinfUpdateRetentionPermisConduireNullableFromJson(
  Object? natinfUpdateRetentionPermisConduire, [
  enums.NatinfUpdateRetentionPermisConduire? defaultValue,
]) {
  if (natinfUpdateRetentionPermisConduire == null) {
    return null;
  }
  return enums.NatinfUpdateRetentionPermisConduire.values.firstWhereOrNull(
          (e) => e.value == natinfUpdateRetentionPermisConduire) ??
      defaultValue;
}

String natinfUpdateRetentionPermisConduireExplodedListToJson(
    List<enums.NatinfUpdateRetentionPermisConduire>?
        natinfUpdateRetentionPermisConduire) {
  return natinfUpdateRetentionPermisConduire?.map((e) => e.value!).join(',') ??
      '';
}

List<String> natinfUpdateRetentionPermisConduireListToJson(
    List<enums.NatinfUpdateRetentionPermisConduire>?
        natinfUpdateRetentionPermisConduire) {
  if (natinfUpdateRetentionPermisConduire == null) {
    return [];
  }

  return natinfUpdateRetentionPermisConduire.map((e) => e.value!).toList();
}

List<enums.NatinfUpdateRetentionPermisConduire>
    natinfUpdateRetentionPermisConduireListFromJson(
  List? natinfUpdateRetentionPermisConduire, [
  List<enums.NatinfUpdateRetentionPermisConduire>? defaultValue,
]) {
  if (natinfUpdateRetentionPermisConduire == null) {
    return defaultValue ?? [];
  }

  return natinfUpdateRetentionPermisConduire
      .map((e) => natinfUpdateRetentionPermisConduireFromJson(e.toString()))
      .toList();
}

List<enums.NatinfUpdateRetentionPermisConduire>?
    natinfUpdateRetentionPermisConduireNullableListFromJson(
  List? natinfUpdateRetentionPermisConduire, [
  List<enums.NatinfUpdateRetentionPermisConduire>? defaultValue,
]) {
  if (natinfUpdateRetentionPermisConduire == null) {
    return defaultValue;
  }

  return natinfUpdateRetentionPermisConduire
      .map((e) => natinfUpdateRetentionPermisConduireFromJson(e.toString()))
      .toList();
}

String? natinfUpdateImmobilisationVehiculeNullableToJson(
    enums.NatinfUpdateImmobilisationVehicule?
        natinfUpdateImmobilisationVehicule) {
  return natinfUpdateImmobilisationVehicule?.value;
}

String? natinfUpdateImmobilisationVehiculeToJson(
    enums.NatinfUpdateImmobilisationVehicule
        natinfUpdateImmobilisationVehicule) {
  return natinfUpdateImmobilisationVehicule.value;
}

enums.NatinfUpdateImmobilisationVehicule
    natinfUpdateImmobilisationVehiculeFromJson(
  Object? natinfUpdateImmobilisationVehicule, [
  enums.NatinfUpdateImmobilisationVehicule? defaultValue,
]) {
  return enums.NatinfUpdateImmobilisationVehicule.values.firstWhereOrNull(
          (e) => e.value == natinfUpdateImmobilisationVehicule) ??
      defaultValue ??
      enums.NatinfUpdateImmobilisationVehicule.swaggerGeneratedUnknown;
}

enums.NatinfUpdateImmobilisationVehicule?
    natinfUpdateImmobilisationVehiculeNullableFromJson(
  Object? natinfUpdateImmobilisationVehicule, [
  enums.NatinfUpdateImmobilisationVehicule? defaultValue,
]) {
  if (natinfUpdateImmobilisationVehicule == null) {
    return null;
  }
  return enums.NatinfUpdateImmobilisationVehicule.values.firstWhereOrNull(
          (e) => e.value == natinfUpdateImmobilisationVehicule) ??
      defaultValue;
}

String natinfUpdateImmobilisationVehiculeExplodedListToJson(
    List<enums.NatinfUpdateImmobilisationVehicule>?
        natinfUpdateImmobilisationVehicule) {
  return natinfUpdateImmobilisationVehicule?.map((e) => e.value!).join(',') ??
      '';
}

List<String> natinfUpdateImmobilisationVehiculeListToJson(
    List<enums.NatinfUpdateImmobilisationVehicule>?
        natinfUpdateImmobilisationVehicule) {
  if (natinfUpdateImmobilisationVehicule == null) {
    return [];
  }

  return natinfUpdateImmobilisationVehicule.map((e) => e.value!).toList();
}

List<enums.NatinfUpdateImmobilisationVehicule>
    natinfUpdateImmobilisationVehiculeListFromJson(
  List? natinfUpdateImmobilisationVehicule, [
  List<enums.NatinfUpdateImmobilisationVehicule>? defaultValue,
]) {
  if (natinfUpdateImmobilisationVehicule == null) {
    return defaultValue ?? [];
  }

  return natinfUpdateImmobilisationVehicule
      .map((e) => natinfUpdateImmobilisationVehiculeFromJson(e.toString()))
      .toList();
}

List<enums.NatinfUpdateImmobilisationVehicule>?
    natinfUpdateImmobilisationVehiculeNullableListFromJson(
  List? natinfUpdateImmobilisationVehicule, [
  List<enums.NatinfUpdateImmobilisationVehicule>? defaultValue,
]) {
  if (natinfUpdateImmobilisationVehicule == null) {
    return defaultValue;
  }

  return natinfUpdateImmobilisationVehicule
      .map((e) => natinfUpdateImmobilisationVehiculeFromJson(e.toString()))
      .toList();
}

String? natinfUpdateMiseEnFourriereNullableToJson(
    enums.NatinfUpdateMiseEnFourriere? natinfUpdateMiseEnFourriere) {
  return natinfUpdateMiseEnFourriere?.value;
}

String? natinfUpdateMiseEnFourriereToJson(
    enums.NatinfUpdateMiseEnFourriere natinfUpdateMiseEnFourriere) {
  return natinfUpdateMiseEnFourriere.value;
}

enums.NatinfUpdateMiseEnFourriere natinfUpdateMiseEnFourriereFromJson(
  Object? natinfUpdateMiseEnFourriere, [
  enums.NatinfUpdateMiseEnFourriere? defaultValue,
]) {
  return enums.NatinfUpdateMiseEnFourriere.values
          .firstWhereOrNull((e) => e.value == natinfUpdateMiseEnFourriere) ??
      defaultValue ??
      enums.NatinfUpdateMiseEnFourriere.swaggerGeneratedUnknown;
}

enums.NatinfUpdateMiseEnFourriere? natinfUpdateMiseEnFourriereNullableFromJson(
  Object? natinfUpdateMiseEnFourriere, [
  enums.NatinfUpdateMiseEnFourriere? defaultValue,
]) {
  if (natinfUpdateMiseEnFourriere == null) {
    return null;
  }
  return enums.NatinfUpdateMiseEnFourriere.values
          .firstWhereOrNull((e) => e.value == natinfUpdateMiseEnFourriere) ??
      defaultValue;
}

String natinfUpdateMiseEnFourriereExplodedListToJson(
    List<enums.NatinfUpdateMiseEnFourriere>? natinfUpdateMiseEnFourriere) {
  return natinfUpdateMiseEnFourriere?.map((e) => e.value!).join(',') ?? '';
}

List<String> natinfUpdateMiseEnFourriereListToJson(
    List<enums.NatinfUpdateMiseEnFourriere>? natinfUpdateMiseEnFourriere) {
  if (natinfUpdateMiseEnFourriere == null) {
    return [];
  }

  return natinfUpdateMiseEnFourriere.map((e) => e.value!).toList();
}

List<enums.NatinfUpdateMiseEnFourriere> natinfUpdateMiseEnFourriereListFromJson(
  List? natinfUpdateMiseEnFourriere, [
  List<enums.NatinfUpdateMiseEnFourriere>? defaultValue,
]) {
  if (natinfUpdateMiseEnFourriere == null) {
    return defaultValue ?? [];
  }

  return natinfUpdateMiseEnFourriere
      .map((e) => natinfUpdateMiseEnFourriereFromJson(e.toString()))
      .toList();
}

List<enums.NatinfUpdateMiseEnFourriere>?
    natinfUpdateMiseEnFourriereNullableListFromJson(
  List? natinfUpdateMiseEnFourriere, [
  List<enums.NatinfUpdateMiseEnFourriere>? defaultValue,
]) {
  if (natinfUpdateMiseEnFourriere == null) {
    return defaultValue;
  }

  return natinfUpdateMiseEnFourriere
      .map((e) => natinfUpdateMiseEnFourriereFromJson(e.toString()))
      .toList();
}

typedef $JsonFactory<T> = T Function(Map<String, dynamic> json);

class $CustomJsonDecoder {
  $CustomJsonDecoder(this.factories);

  final Map<Type, $JsonFactory> factories;

  dynamic decode<T>(dynamic entity) {
    if (entity is Iterable) {
      return _decodeList<T>(entity);
    }

    if (entity is T) {
      return entity;
    }

    if (isTypeOf<T, Map>()) {
      return entity;
    }

    if (isTypeOf<T, Iterable>()) {
      return entity;
    }

    if (entity is Map<String, dynamic>) {
      return _decodeMap<T>(entity);
    }

    return entity;
  }

  T _decodeMap<T>(Map<String, dynamic> values) {
    final jsonFactory = factories[T];
    if (jsonFactory == null || jsonFactory is! $JsonFactory<T>) {
      return throw "Could not find factory for type $T. Is '$T: $T.fromJsonFactory' included in the CustomJsonDecoder instance creation in bootstrapper.dart?";
    }

    return jsonFactory(values);
  }

  List<T> _decodeList<T>(Iterable values) =>
      values.where((v) => v != null).map<T>((v) => decode<T>(v) as T).toList();
}

class $JsonSerializableConverter extends chopper.JsonConverter {
  @override
  FutureOr<chopper.Response<ResultType>> convertResponse<ResultType, Item>(
      chopper.Response response) async {
    if (response.bodyString.isEmpty) {
      // In rare cases, when let's say 204 (no content) is returned -
      // we cannot decode the missing json with the result type specified
      return chopper.Response(response.base, null, error: response.error);
    }

    if (ResultType == String) {
      return response.copyWith();
    }

    if (ResultType == DateTime) {
      return response.copyWith(
          body: DateTime.parse((response.body as String).replaceAll('"', ''))
              as ResultType);
    }

    final jsonRes = await super.convertResponse(response);
    return jsonRes.copyWith<ResultType>(
        body: $jsonDecoder.decode<Item>(jsonRes.body) as ResultType);
  }
}

final $jsonDecoder = $CustomJsonDecoder(generatedMapping);

// ignore: unused_element
String? _dateToJson(DateTime? date) {
  if (date == null) {
    return null;
  }

  final year = date.year.toString();
  final month = date.month < 10 ? '0${date.month}' : date.month.toString();
  final day = date.day < 10 ? '0${date.day}' : date.day.toString();

  return '$year-$month-$day';
}

class Wrapped<T> {
  final T value;
  const Wrapped.value(this.value);
}
