import 'package:flutter/material.dart';
import 'package:natinfo_flutter/api/swagger.swagger.dart';
import 'package:natinfo_flutter/db/database_helper.dart';
import 'package:natinfo_flutter/pages/natinf_details.dart';
import 'package:natinfo_flutter/providers/theme_provider.dart';
import 'package:provider/provider.dart';

class NatinfList extends StatelessWidget {
  final List<Natinf> natinfList;
  final bool recordHistory;
  const NatinfList({super.key, required this.natinfList, this.recordHistory = true});

  @override
  Widget build(BuildContext context) {
    // Determine la couleur du background en fonction du type d'infraction
    Color getBackgroundColor(BuildContext context, String? natureInfraction) {
      if (natureInfraction == null) return Colors.transparent;
      final lower = natureInfraction.toLowerCase();
      final themeProvider = Provider.of<ThemeProvider>(context, listen: false);
      if (lower.contains('crime')) return themeProvider.crimeColor;
      if (lower.contains('delit') || lower.contains('délit')) return themeProvider.delitColor;
      if (lower.contains('contravention')) return themeProvider.contraventionColor;
      return Colors.transparent;
    }

    return ListView.builder(
      physics: const BouncingScrollPhysics(),
      itemCount: natinfList.length,
      itemBuilder: (context, index) {
        final natinf = natinfList[index];
        return Container(
          color: getBackgroundColor(context, natinf.natureInfraction),
          child: ListTile(
            title: Text(natinf.numeroNatinf ?? ''),
            subtitle: Column(
              crossAxisAlignment: CrossAxisAlignment.start,
              children: [
                Text('${natinf.natureInfraction}'),
                Text('${natinf.qualificationInfraction}'),
              ],
            ),
            onTap: () async {
              if (recordHistory) {
                await DatabaseHelper().addHistory(natinf.numeroNatinf ?? '');
              }
              Navigator.push(
                context,
                MaterialPageRoute(
                  builder: (context) => NatinfDetail(natinf: natinf),
                ),
              );
            },
          ),
        );
      },
    );
  }
}